@@ -14,7 +14,7 @@ require 'forwardable'
 #   conn.get '/'
 #
 module Faraday
-  VERSION = "0.9.1"
+  VERSION = "0.17.3"
 
   class << self
     # Public: Gets or sets the root path that Faraday is being loaded from.
@@ -34,8 +34,8 @@ module Faraday
     #     Faraday.get "https://faraday.com"
     attr_writer :default_connection
 
-    # Public: Sets the default options used when calling Faraday#new.
-    attr_writer :default_connection_options
+    # Public: Tells faraday to ignore the environment proxy (http_proxy).
+    attr_accessor :ignore_env_proxy
 
     # Public: Initializes a new Faraday::Connection.
     #
@@ -64,9 +64,8 @@ module Faraday
     #     :params => {:page => 1}
     #
     # Returns a Faraday::Connection.
-    def new(url = nil, options = nil)
-      block = block_given? ? Proc.new : nil
-      options = options ? default_connection_options.merge(options) : default_connection_options.dup
+    def new(url = nil, options = nil, &block)
+      options = options ? default_connection_options.merge(options) : default_connection_options
       Faraday::Connection.new(url, options, &block)
     end
 
@@ -92,6 +91,10 @@ module Faraday
 
     alias require_lib require_libs
 
+    def respond_to?(symbol, include_private = false)
+      default_connection.respond_to?(symbol, include_private) || super
+    end
+
   private
     # Internal: Proxies method calls on the Faraday constant to
     # #default_connection.
@@ -100,6 +103,7 @@ module Faraday
     end
   end
 
+  self.ignore_env_proxy = false
   self.root_path = File.expand_path "..", __FILE__
   self.lib_path = File.expand_path "../faraday", __FILE__
   self.default_adapter = :net_http
@@ -108,7 +112,7 @@ module Faraday
   #
   # Returns a Faraday::Connection, configured with the #default_adapter.
   def self.default_connection
-    @default_connection ||= Connection.new
+    @default_connection ||= Connection.new(default_connection_options)
   end
 
   # Gets the default connection options used when calling Faraday#new.
@@ -118,13 +122,10 @@ module Faraday
     @default_connection_options ||= ConnectionOptions.new
   end
 
-  if (!defined?(RUBY_ENGINE) || "ruby" == RUBY_ENGINE) && RUBY_VERSION < '1.9'
-    begin
-      require 'system_timer'
-      Timer = SystemTimer
-    rescue LoadError
-      warn "Faraday: you may want to install system_timer for reliable timeouts"
-    end
+  # Public: Sets the default options used when calling Faraday#new.
+  def self.default_connection_options=(options)
+    @default_connection = nil
+    @default_connection_options = ConnectionOptions.from(options)
   end
 
   unless const_defined? :Timer
@@ -244,25 +245,3 @@ module Faraday
     require_lib 'autoload'
   end
 end
-
-# not pulling in active-support JUST for this method.  And I love this method.
-class Object
-  # The primary purpose of this method is to "tap into" a method chain,
-  # in order to perform operations on intermediate results within the chain.
-  #
-  # Examples
-  #
-  #   (1..10).tap { |x| puts "original: #{x.inspect}" }.to_a.
-  #     tap    { |x| puts "array: #{x.inspect}" }.
-  #     select { |x| x%2 == 0 }.
-  #     tap    { |x| puts "evens: #{x.inspect}" }.
-  #     map    { |x| x*x }.
-  #     tap    { |x| puts "squares: #{x.inspect}" }
-  #
-  # Yields self.
-  # Returns self.
-  def tap
-    yield(self)
-    self
-  end unless Object.respond_to?(:tap)
-end
